@@ -1,7 +1,7 @@
 import pytest
 
-from numerous_image_tools.image_test import build_image
-from numerous_image_tools.image_test import run_container
+from numerous_image_tools.image_test.build import build_image
+from numerous_image_tools.image_test.run import run_container
 
 def pytest_namespace():
     return {'image': None}
